@@ -2,6 +2,7 @@ import requests
 from odin.models.certificate_search_response_model import CertificateSearchResponse
 from odin.models.get_host_count import GetHostsCountResponse
 from odin.models.get_hosts_ip_details_response import GetHostsIpDetailsResponse
+from odin.models.get_hosts_cve_details import CVEDetailsResponse
 from odin.models.search_hosts_response_model import SearchHostsResponse
 from odin.models.get_hosts_summary_response import GetHostSummaryResponse
 from odin.models.get_certificate_count import GetCertificatesCountResponse
@@ -42,8 +43,16 @@ class OdinClient:
         response = self.make_request(url, req, "POST")
         return GetHostsCountResponse(response)
     
-    def test():
-        print("hey 2")
+    def get_hosts_cve_details(self, query):
+        """
+        Fetch the latest cve details
+        Returns the complete cve details
+        return: CVEDetailsResponse
+        """
+        endpoint = "/hosts/cve/"
+        url = self.base_url + endpoint + query
+        response = self.make_request(url, None, "GET")
+        return CVEDetailsResponse(response)
                   
     def get_hosts_ip_details(self, query):
         """
